@@ -2,11 +2,14 @@
 #
 # File: test/integration/conftest.py
 #
-# Copyright 2021 Backblaze Inc. All Rights Reserved.
+# Copyright 2025 Backblaze Inc. All Rights Reserved.
 #
 # License https://www.backblaze.com/using_b2_code.html
 #
 ######################################################################
+import pytest
 
 
-pytest_plugins = ['b2sdk.v3.testing']
+@pytest.fixture(scope='session', autouse=True)
+def auto_change_account_info_dir(change_account_info_dir):
+    pass
